#!/usr/bin/env python

# Edited by Rui Zhang @ NCMI

from EMAN import *
from sys import argv
try:
        from optparse import OptionParser
except:
        from optik import OptionParser


def main():
    usage = """This program will chop a tall image into overlapping pieces
    Usage: %prog <infile> <outfile> [options]"""
    parser = OptionParser(usage = usage)
    
    parser.add_option("--width", dest = "width",type = "int", help = "The width of particles, can be different from the width of infile.", default = -1)
    parser.add_option("--length", dest = "length", type = "int", help = "The length of particles, can be different from the width.", default = -1)
    parser.add_option("--vstep", dest = "vstep", type = "int", help = "The vertical step size during chopping. The value is usually 10% of the length, resulting in 90% overlap between successive particles", default = -1)
    
    (options, args) = parser.parse_args()
    
    if len(args) < 2:
        print "### Error ! Please specify input and ouput ! ###"
        parser.print_help()
        sys.exit(-1)
    
    infile = args[0]
    outfile = args[1]
    d = EMData()
    d.readImage(infile,0)
    
    if options.width < 0:
        print "By default, the width of particles is set to the width of input image, which is %d"%(d.xSize())
        options.width = d.xSize()
    if options.length < 0:
        print "By default, the length of particles is equal to the width, which is %d"%(options.width)
        options.length = options.width
    if options.vstep < 0:
        print "By default, the vstep is set to 10%% of the length, which is %d"%(int(options.length*0.1))
        options.vstep = int(options.length*0.1)
    
    n,imgtype = fileCount(infile)
    if n > 1:
        print "Warning: input image file is a stack file"
    
    for i in range(n):
        d.readImage(infile,i)
        for j in range(0, d.ySize()-options.length+1, options.vstep):
            x = d.clip((d.xSize()-options.width)/2,j,options.width,options.length)
            x.writeImage(outfile,-1)

if __name__ == "__main__":
    main()
